function fp = FilterParam(fclass, type, order, w, R)
% FILTERPARAM Creates Filter Parameter structure
% FILTERPARAM(fclass, type, N, w, R)
% inputs:
%
% fclass    : class of filter
%               0 or 'butter' : Butterworth
%               1 or 'bessel' : Bessel
%               2 or 'cheby1' : Chebyshev type I.
%               3 or 'cheby2' : Chebyshev type II.
%               4 or 'ellip'  : Elliptic
%
% type      : filter type
%               0 or 'lowpass'
%               1 or 'highpass'
%               2 or 'bandpass'
%               3 or 'bandstop'
%
% order     : Order
%
% w         : Frequency (vector)
%               A two dimensional vector, the first element used as cutoff
%               frequency for low- and highpass filters, the second element
%               used by bandpass and -stop filters as the second frequency,
%               for other filters this element is discarded.
%
% R         : Ripple (vector)
%               First element : peak-to-peak ripple [dB] (if filter has this
%               parameter)
%               Second element : minimum stopband attenuation [dB] (if
%               filter has this parameter)
%
%  Examples:
%
%   fp=FilterParam('butter', 0, 4, 0.2);
%   fp=FilterParam(2, 3, 8, [0.25 0.4], 0.2);

fclass_=0;
if(ischar(fclass))
    switch lower(fclass)
        case 'butter'
            fclass_ = 0;
        case 'bessel'
            fclass_ = 1;
        case 'cheby1'
            fclass_ = 2;
        case 'cheby2'
            fclass_ = 3;
        case 'ellip'
            fclass_ = 4;
        otherwise
            error('Filter class specifier is invalid!');
    end;
elseif(isnumeric(fclass))
    if(length(fclass)>1)
        error('Filter class parameter must be a scalar or a char array!');
    else
        if((fclass>4)||(fclass<0))
            error('Filter class parameter must be in the range of 0..4!');
        else
            fclass_=fclass;
        end;
    end;
else
    error('Filter class parameter has invalid type!');
end;

type_=0;
if(ischar(type))
    switch lower(type)
        case 'lowpass'
            type_ = 0;
        case 'highpass'
            type_ = 1;
        case 'bandpass'
            type_ = 2;
        case 'bandstop'
            type_ = 3;
        otherwise
            error('Type specifier is invalid!');
    end;
elseif(isnumeric(type))
    if(length(type)>1)
        error('Type parameter must be a scalar or a char array!');
    else
        if((type>3)||(type<0))
            error('Type parameter must be in the range of 0..3!');
        else
            type_=type;
        end;
    end;
else
    error('Type parameter has invalid type!');
end;

if(~isnumeric(order)||length(order)~=1)
    error('Order parameter must be scalar!');
elseif(order<1)
    error('Order must be at least 1!');
end;

w_=[0 0];
R_=[0 0];

switch(type_)
    case {0, 1}
        switch(length(w))
            case 1
                w_=[w 0];
            case 2
                w_=w;
            otherwise
                error('Frequency parameter must be a one or two dimensional array!');
        end;
    case {2, 3}
        if(length(w)~=2) error('Frequency parameter must be a two dimensional array!'); end;
        w_=w;
end;

switch(fclass_)
    case {2, 3}
        switch(length(R))
            case 1
                R_=[R 0];
            case 2
                R_=R;
            otherwise
                error('Ripple parameter must be a one or two dimensional array!');
        end;
    case 4
        if(length(R)~=2) error('Ripple parameter must be a two dimensional array!'); end;
        R_=R;
end;

fp = struct('fclass', fclass_, 'type', type_, 'order', order, 'w', w_, 'R', R_);